@@ -12,9 +12,11 @@ MainWindow::MainWindow(QWidget *parent) :
 #endif
     ui->labelUnsupportedKernel->hide();
     ui->vbusOffButton->hide();
+    ui->unmountButton->hide();
     ui->vbusOnButton->setEnabled(false);
     ui->enumerateButton->setEnabled(false);
     ui->mountButton->setEnabled(false);
+    ui->helpButton->setIcon(QPixmap(":/general_help.png"));
     // Connect buttons to functions.
     connectButtons();
     // Make status bar say Ready.
@@ -54,9 +56,11 @@ void MainWindow::connectButtons()
     connect(ui->HShostmode, SIGNAL(clicked()), this, SLOT(hostmodeHS()));
     connect(ui->LShostmode, SIGNAL(clicked()), this, SLOT(hostmodeLS()));
     connect(ui->enumerateButton, SIGNAL(clicked()), this, SLOT(enumerate()));
-    connect(ui->mountButton, SIGNAL(clicked()), this, SLOT(mountdevsda1()));
+    connect(ui->mountButton, SIGNAL(clicked()), this, SLOT(mount()));
+    connect(ui->unmountButton, SIGNAL(clicked()), this, SLOT(unmount()));
     connect(ui->vbusOnButton, SIGNAL(clicked()), this, SLOT(vbusOn()));
     connect(ui->vbusOffButton, SIGNAL(clicked()), this, SLOT(vbusOff()));
+    connect(ui->helpButton, SIGNAL(clicked()), this, SLOT(helpWindow()));
 #ifdef Q_WS_MAEMO_5
     connect(QApplication::desktop(), SIGNAL(resized(int)), this, SLOT(orientationChanged()));
 #endif
@@ -71,7 +75,7 @@ void MainWindow::vbusOn()
     ui->FShostmode->setEnabled(false);
     ui->LShostmode->setEnabled(false);
 #ifdef Q_WS_MAEMO_5
-    system("booston");
+    system("booston &");
 #endif
     ui->statusBar->showMessage(ui->statusBar->currentMessage() + tr(" - VBUS on"));
 }
@@ -88,13 +92,20 @@ void MainWindow::vbusOff()
     ui->LShostmode->setEnabled(true);
     ui->enumerateButton->setEnabled(false);
     ui->mountButton->setEnabled(false);
+    ui->unmountButton->hide();
     ui->vbusOnButton->setEnabled(false);
     ui->statusBar->showMessage(tr("VBUS disabled"));
 }
 
-void MainWindow::mountdevsda1()
+void MainWindow::mount()
 {
-    system("mkdir -p /media/flash && mount /dev/sda1 /media/flash");
+    system("/opt/h-e-n/mount.sh --mount");
+    ui->unmountButton->show();
+}
+
+void MainWindow::unmount()
+{
+    system("/opt/h-e-n/mount.sh --unmount");
 }
 
 void MainWindow::kernelcheck()
